Generate a template for this exploit with `pwnkit`:
```
pip install pwnkit
pwnkit xpl.py -f ./travelgraph -l ./libc.so.6 -t heap
```

## Writeup
CTF writeup: https://4xura.com/writeups-for-ctfs/pwn-travelgraph/
About Largebin Attack: https://4xura.com/binex/heap/large-bin-attack/

## Memos

* House of Apple
* Largebin Attack
* Heap fengshui
* Heap UAF
* IO Struct Exploit
* glibc 2.35


